@@ -7,16 +7,18 @@ echo "Copying file to /usr/local/goip$1"
 if [ $# = 1 ] ; then
  cp -rf goip goip$1
 fi
+cp -rf /usr/local/goip/inc/config.inc.php /usr/local/goip/inc/config.inc.php0
 cp -rf goip$1 /usr/local/
 chmod -R 777 /usr/local/goip$1
 
 cd /usr/local/goip$1/
+mv -f /usr/local/goip/inc/config.inc.php0 /usr/local/goip/inc/config.inc.php 
 
 if [ $# = 1 ] ; then
 cp goipcron goipcron$1
-port=`expr $1 + 44444`
-sed -i "s/='goip'/='goip$1'/g" inc/config.inc.php 
-sed -i "s/44444/$port/g" inc/config.inc.php
+#port=`expr $1 + 44444`
+#sed -i "s/='goip'/='goip$1'/g" inc/config.inc.php 
+#sed -i "s/44444/$port/g" inc/config.inc.php
 
 echo "#!/bin/sh
 
